# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action_copy_to_clipboard_content


# Copies data to the clipboard.
class DivActionCopyToClipboard(BaseDiv):

    def __init__(
        self, *,
        type: str = "copy_to_clipboard",
        content: typing.Optional[div_action_copy_to_clipboard_content.DivActionCopyToClipboardContent] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            content=content,
            **kwargs,
        )

    type: str = Field(default="copy_to_clipboard")
    content: div_action_copy_to_clipboard_content.DivActionCopyToClipboardContent = Field(
    )


DivActionCopyToClipboard.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_translation


# Translation transformation.
class DivTranslationTransformation(BaseDiv):

    def __init__(
        self, *,
        type: str = "translation",
        x: typing.Optional[div_translation.DivTranslation] = None,
        y: typing.Optional[div_translation.DivTranslation] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            x=x,
            y=y,
            **kwargs,
        )

    type: str = Field(default="translation")
    x: typing.Optional[div_translation.DivTranslation] = Field(
        description="X coordinate of the translation.",
    )
    y: typing.Optional[div_translation.DivTranslation] = Field(
        description="Y coordinate of the translation.",
    )


DivTranslationTransformation.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Controls the timer.
class DivActionTimer(BaseDiv):

    def __init__(
        self, *,
        type: str = "timer",
        action: typing.Optional[typing.Union[Expr, DivActionTimerAction]] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            action=action,
            id=id,
            **kwargs,
        )

    type: str = Field(default="timer")
    action: typing.Union[Expr, DivActionTimerAction] = Field(
        description=(
            "Timer actions:`start` — starts the timer from a stopped "
            "state`stop`— stops thetimer and performs the `onEnd` "
            "action`pause` — pauses the timer, saves thecurrent "
            "time`resume` — restarts the timer after a pause`cancel` — "
            "interrupts thetimer, resets the time`reset` — cancels the "
            "timer, then starts it again"
        ),
    )
    id: typing.Union[Expr, str] = Field(
        description="Timer ID.",
    )


class DivActionTimerAction(str, enum.Enum):
    START = "start"
    STOP = "stop"
    PAUSE = "pause"
    RESUME = "resume"
    CANCEL = "cancel"
    RESET = "reset"


DivActionTimer.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action_typed, div_download_callbacks


# It defines an action when clicking on an element.
class DivAction(BaseDiv):

    def __init__(
        self, *,
        download_callbacks: typing.Optional[div_download_callbacks.DivDownloadCallbacks] = None,
        is_enabled: typing.Optional[typing.Union[Expr, bool]] = None,
        log_id: typing.Optional[typing.Union[Expr, str]] = None,
        log_url: typing.Optional[typing.Union[Expr, str]] = None,
        menu_items: typing.Optional[typing.Sequence[DivActionMenuItem]] = None,
        payload: typing.Optional[typing.Dict[str, typing.Any]] = None,
        referer: typing.Optional[typing.Union[Expr, str]] = None,
        scope_id: typing.Optional[typing.Union[Expr, str]] = None,
        target: typing.Optional[typing.Union[Expr, DivActionTarget]] = None,
        typed: typing.Optional[div_action_typed.DivActionTyped] = None,
        url: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            download_callbacks=download_callbacks,
            is_enabled=is_enabled,
            log_id=log_id,
            log_url=log_url,
            menu_items=menu_items,
            payload=payload,
            referer=referer,
            scope_id=scope_id,
            target=target,
            typed=typed,
            url=url,
            **kwargs,
        )

    download_callbacks: typing.Optional[div_download_callbacks.DivDownloadCallbacks] = Field(
        description=(
            "Callbacks that are called after [data "
            "loading](../../interaction#loading-data)."
        ),
    )
    is_enabled: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "The parameter disables the action. Disabled actions stop "
            "listening to theirassociated event (clicks, changes in "
            "visibility, and so on)."
        ),
    )
    log_id: typing.Union[Expr, str] = Field(
        description="Logging ID.",
    )
    log_url: typing.Optional[typing.Union[Expr, str]] = Field(
        format="uri", 
        description="URL for logging.",
    )
    menu_items: typing.Optional[typing.Sequence[DivActionMenuItem]] = Field(
        description="Context menu.",
    )
    payload: typing.Optional[typing.Dict[str, typing.Any]] = Field(
        description="Additional parameters, passed to the host application.",
    )
    referer: typing.Optional[typing.Union[Expr, str]] = Field(
        format="uri", 
        description="Referer URL for logging.",
    )
    scope_id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "The ID of the element within which the specified action "
            "will be performed."
        ),
    )
    target: typing.Optional[typing.Union[Expr, DivActionTarget]] = Field(
        description="The tab in which the URL must be opened.",
    )
    typed: typing.Optional[div_action_typed.DivActionTyped] = Field(
    )
    url: typing.Optional[typing.Union[Expr, str]] = Field(
        format="uri", 
        description=(
            "URL. Possible values: `url` or `div-action://`. To learn "
            "more, see [Interactionwith elements](../../interaction)."
        ),
    )


class DivActionTarget(str, enum.Enum):
    SELF = "_self"
    BLANK = "_blank"


class DivActionMenuItem(BaseDiv):

    def __init__(
        self, *,
        action: typing.Optional[DivAction] = None,
        actions: typing.Optional[typing.Sequence[DivAction]] = None,
        text: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            action=action,
            actions=actions,
            text=text,
            **kwargs,
        )

    action: typing.Optional[DivAction] = Field(
        description=(
            "One action when clicking on a menu item. Not used if the "
            "`actions` parameter isset."
        ),
    )
    actions: typing.Optional[typing.Sequence[DivAction]] = Field(
        description="Multiple actions when clicking on a menu item.",
    )
    text: typing.Union[Expr, str] = Field(
        description="Menu item title.",
    )


DivActionMenuItem.update_forward_refs()


DivAction.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_currency_input_mask, div_fixed_length_input_mask, div_phone_input_mask,
)


DivInputMask = Union[
    div_fixed_length_input_mask.DivFixedLengthInputMask,
    div_currency_input_mask.DivCurrencyInputMask,
    div_phone_input_mask.DivPhoneInputMask,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_edge_insets


# Cloud-style text background. Rows have a rectangular background in the specified
# color with rounded corners.
class DivCloudBackground(BaseDiv):

    def __init__(
        self, *,
        type: str = "cloud",
        color: typing.Optional[typing.Union[Expr, str]] = None,
        corner_radius: typing.Optional[typing.Union[Expr, int]] = None,
        paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            color=color,
            corner_radius=corner_radius,
            paddings=paddings,
            **kwargs,
        )

    type: str = Field(default="cloud")
    color: typing.Union[Expr, str] = Field(
        format="color", 
        description="Fill color.",
    )
    corner_radius: typing.Union[Expr, int] = Field(
        description="Corner rounding radius.",
    )
    paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = Field(
        description="Margins between the row border and background border.",
    )


DivCloudBackground.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_radial_gradient_fixed_center, div_radial_gradient_relative_center,
)


DivRadialGradientCenter = Union[
    div_radial_gradient_fixed_center.DivRadialGradientFixedCenter,
    div_radial_gradient_relative_center.DivRadialGradientRelativeCenter,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Location of the coordinate of the rotation axis as a percentage relative to the
# element size.
class DivPivotPercentage(BaseDiv):

    def __init__(
        self, *,
        type: str = "pivot-percentage",
        value: typing.Optional[typing.Union[Expr, float]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            value=value,
            **kwargs,
        )

    type: str = Field(default="pivot-percentage")
    value: typing.Union[Expr, float] = Field(
        description="Coordinate value as a percentage.",
    )


DivPivotPercentage.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# A mask to hide text (spoiler). Looks like a rectangle filled with the color
# specified in the `color` parameter, same as in Telegram.
class DivTextRangeMaskSolid(BaseDiv):

    def __init__(
        self, *,
        type: str = "solid",
        color: typing.Optional[typing.Union[Expr, str]] = None,
        is_enabled: typing.Optional[typing.Union[Expr, bool]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            color=color,
            is_enabled=is_enabled,
            **kwargs,
        )

    type: str = Field(default="solid")
    color: typing.Union[Expr, str] = Field(
        format="color", 
        description="Color.",
    )
    is_enabled: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Controls the mask state. If set to `true`, the mask will "
            "hide the specified partof text. Otherwise, the text will be "
            "shown."
        ),
    )


DivTextRangeMaskSolid.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_size_unit


# It sets margins.
class DivEdgeInsets(BaseDiv):

    def __init__(
        self, *,
        bottom: typing.Optional[typing.Union[Expr, int]] = None,
        end: typing.Optional[typing.Union[Expr, int]] = None,
        left: typing.Optional[typing.Union[Expr, int]] = None,
        right: typing.Optional[typing.Union[Expr, int]] = None,
        start: typing.Optional[typing.Union[Expr, int]] = None,
        top: typing.Optional[typing.Union[Expr, int]] = None,
        unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            bottom=bottom,
            end=end,
            left=left,
            right=right,
            start=start,
            top=top,
            unit=unit,
            **kwargs,
        )

    bottom: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Bottom margin.",
    )
    end: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "End margin. Margin position depends on the interface "
            "orientation. Has higherpriority than the left and right "
            "margins."
        ),
    )
    left: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Left margin.",
    )
    right: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Right margin.",
    )
    start: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Start margin. Margin position depends on the interface "
            "orientation. Has higherpriority than the left and right "
            "margins."
        ),
    )
    top: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Top margin.",
    )
    unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = Field(
    )


DivEdgeInsets.update_forward_refs()
